Link

Struct Link 

pub struct Link<Message: NetworkMessage> { /* private fields */ }
Each link consists of two messages queues, one for each direction

Implementations

Source

impl<Message: NetworkMessage> Link<Message>

pub fn get_processes(&self) -> (Rc<Process<Message>>, Rc<Process<Message>>)

Get the two processs connected with this link Always sorted by smallest id first

pub fn send(self_ptr: &Rc<Link<Message>>, source: ProcessId, message: Message)

pub fn num_total_messages(&self) -> u64

Get the number of all messages ever sent through this link