pub struct Link<Message: NetworkMessage> { /* private fields */ }Expand description
Each link consists of two messages queues, one for each direction
Implementations
Sourceimpl<Message: NetworkMessage> Link<Message>
impl<Message: NetworkMessage> Link<Message>
Sourcepub fn get_processes(&self) -> (Rc<Process<Message>>, Rc<Process<Message>>)
pub fn get_processes(&self) -> (Rc<Process<Message>>, Rc<Process<Message>>)
Get the two processs connected with this link Always sorted by smallest id first
pub fn send(self_ptr: &Rc<Link<Message>>, source: ProcessId, message: Message)
Sourcepub fn num_total_messages(&self) -> u64
pub fn num_total_messages(&self) -> u64
Get the number of all messages ever sent through this link